pub fn render_key(
template: &str,
m: &Metadata,
safekey: &str,
) -> Result<String, KeyTemplateError>Expand description
The key template gives m, whose safekey is safekey.
Errors
KeyTemplateError for an unknown placeholder or an unclosed {.