pub fn disambiguate(key: String, used: &mut HashSet<String>) -> String
Suffix a key that already appears in used with a, b, … (the biblatex convention for the same author and year), and record it.
used
a
b